@@ -27,7 +27,7 @@
 class TestSolver: public QObject
 {
     Q_OBJECT
-private slots:
+private Q_SLOTS:
     void runSolver();
 };
 
