@@ -37,21 +37,27 @@
 
 #include "dealerinfo.h"
 
-// KF
-#include <KLocalizedString>
+static QString createBaseIdString(const KLocalizedString &baseName)
+{
+    QString result;
 
-DealerInfo::DealerInfo(const KLazyLocalizedString &untranslatedBaseName, int baseId)
+    const QString untranslatedBaseName = QString::fromUtf8(baseName.untranslatedText());
+    result.reserve(untranslatedBaseName.size());
+    for (QChar c : untranslatedBaseName) {
+        if (c.isLetterOrNumber())
+            result += c.toLower();
+    }
+    result.squeeze();
+    return result;
+}
+
+DealerInfo::DealerInfo(const KLocalizedString &untranslatedBaseName, int baseId, const QMap<int, KLocalizedString> &subTypes)
     : m_baseName(untranslatedBaseName)
+    , m_baseIdString(createBaseIdString(untranslatedBaseName))
     , m_baseId(baseId)
+    , m_subtypes(subTypes)
 {
     DealerInfoList::self()->add(this);
-
-    QString baseName = QString::fromUtf8(m_baseName.untranslatedText());
-    for (int i = 0; i < baseName.size(); ++i) {
-        QChar c = baseName.at(i);
-        if (c.isLetterOrNumber())
-            m_baseIdString += c.toLower();
-    }
 }
 
 DealerInfo::~DealerInfo()
@@ -78,11 +84,6 @@ int DealerInfo::baseId() const
     return m_baseId;
 }
 
-void DealerInfo::addSubtype(int id, const KLazyLocalizedString &untranslatedName)
-{
-    m_subtypes.insert(id, untranslatedName);
-}
-
 QList<int> DealerInfo::subtypeIds() const
 {
     return m_subtypes.keys();
@@ -106,7 +107,7 @@ QString DealerInfo::nameForId(int id) const
     if (id == m_baseId)
         return baseName();
 
-    QMap<int, KLazyLocalizedString>::const_iterator it = m_subtypes.find(id);
+    auto it = m_subtypes.find(id);
     if (it != m_subtypes.constEnd())
         return it.value().toString();
     else
