@@ -263,7 +263,7 @@ void CardThemeDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt
         painter->drawPixmap(previewRect.topLeft(), *pix);
     } else {
         painter->fillRect(previewRect, QColor(0, 0, 0, 16));
-        painter->drawText(previewRect, Qt::AlignCenter, i18n("Loading..."));
+        painter->drawText(previewRect, Qt::AlignCenter, i18nc("@info", "Loading…"));
     }
 
     QRect textRect = option.rect.adjusted(0, 0, 0, -d->itemMargin);
@@ -349,8 +349,7 @@ KCardThemeWidget::KCardThemeWidget(const QSet<QString> &requiredFeatures, const
     connect(d->listView->selectionModel(), &QItemSelectionModel::currentChanged, d, &KCardThemeWidgetPrivate::updateLineEdit);
     connect(d->hiddenLineEdit, &QLineEdit::textChanged, d, &KCardThemeWidgetPrivate::updateListView);
 
-    d->newDeckButton = new KNSWidgets::Button(this);
-    d->newDeckButton->setConfigFile(QStringLiteral("kcardtheme.knsrc"));
+    d->newDeckButton = new KNSWidgets::Button(i18nc("@action:button", "Download New Card Decks…"), QStringLiteral("kcardtheme.knsrc"), this);
     QObject::connect(d->newDeckButton, &KNSWidgets::Button::dialogFinished, this, [this](const QList<KNSCore::Entry> &changedEntries) {
         if (!changedEntries.isEmpty()) {
             d->model->reload();
